.. _esp32_tutorial:

MicroPython tutorial for ESP32
==============================

This tutorial is intended to get you started using MicroPython on the ESP32
system-on-a-chip.  If it is your first time it is recommended to follow the
tutorial through in the order below.  Otherwise the sections are mostly self
contained, so feel free to skip to those that interest you.

The tutorial does not assume that you know Python, but it also does not attempt
to explain any of the details of the Python language.  Instead it provides you
with commands that are ready to run, and hopes that you will gain a bit of
Python knowledge along the way.  To learn more about Python itself please refer
to `<https://www.python.org>`__.

.. toctree::
   :maxdepth: 1
   :numbered:

   intro.rst
   pwm.rst
   peripheral_access.rst
